@@ -52,7 +52,7 @@ class Domoticz(IPlugin):
 #				log.msg("resp  :  %s" % (req))				
 #				resp = requests.get (req)
 				log.msg("resp  :  %s" % (resp))
-		if bodies ="":
+		if bodies == "":
 			bodies = "j'ai rien compris"
 		return {"plugin": "Domoticz",
 			"method": "switchlight",
